@@ -13,6 +13,12 @@ def disconnect_db(conn, cur):
 
 
 def get_sitemap_parent():
+    """
+    Retrieve sitemaps where the date of last modification is null.
+    Sitemaps with lastmod null are the root of the sitemap tree of a website.
+
+    :return: list of root sitemaps
+    """
     conn = None
     cur = None
     try:
@@ -29,6 +35,11 @@ def get_sitemap_parent():
 
 
 def get_all_sitemap():
+    """
+    Request all sitemaps.
+
+    :return: list of all sitemaps
+    """
     conn = None
     cur = None
     try:
@@ -45,6 +56,12 @@ def get_all_sitemap():
 
 
 def get_sitemap(id):
+    """
+    Request a specific sitemap with its url.
+
+    :param id: url of the sitemap
+    :return: the sitemap if present, None otherwise
+    """
     conn = None
     cur = None
     try:
@@ -61,6 +78,12 @@ def get_sitemap(id):
 
 
 def update_sitemap(id, data):
+    """
+    Update the date of last modification of a sitemap.
+
+    :param id: url of the sitemap
+    :param data: new date of last modification
+    """
     conn = None
     cur = None
     try:
@@ -75,14 +98,22 @@ def update_sitemap(id, data):
         disconnect_db(conn, cur)
 
 
-def insert_sitemap(loc, lasmod, url_headers, id_trust):
+def insert_sitemap(loc, lastmod, url_headers, id_trust):
+    """
+    Insert a new sitemap in the database.
+
+    :param loc: url of the sitemap
+    :param lastmod: date of last modification of the sitemap, None if root sitemap
+    :param url_headers: xml tags to retrieve in the content of the sitemap in the url tag
+    :param id_trust: id of the trust level in the news website
+    """
     conn = None
     cur = None
     try:
         conn = connect_db()
         cur = conn.cursor()
         query = """insert into sitemap values (%s, %s, %s, %s)"""
-        cur.execute(query, (loc, lasmod, url_headers, id_trust))
+        cur.execute(query, (loc, lastmod, url_headers, id_trust))
         conn.commit()
     except (Exception, psycopg2.DatabaseError) as error:
         print(error)
@@ -91,6 +122,11 @@ def insert_sitemap(loc, lasmod, url_headers, id_trust):
 
 
 def get_trust_levels():
+    """
+    Retrieve all trust levels with their id and label.
+
+    :return: list of trust levels
+    """
     conn = None
     cur = None
     try:
